# img_resizer - easy to resize image for iOS app

![img_resizer demo](/screencast.gif?raw=true )

# Installation

``
pip install img_resizer
``

# Usage

    img_resizer --help
    Options:
        --path TEXT    the directory of images (default: ".")
        --format TEXT  image format (default: png)
        --postfix TEXT  mapping @3x image (default: @3x.png)

